#include "box.hpp"

Box::Box(int rbx, int rby, int rbwidth, int rbheight,
		       COLOR_TYPE border,
		       COLOR_TYPE fill) :

	Icon(-1, -1, -1, -1)
{
	x1 = rbx;
	y1 = rby;
	x2 = x1 + rbwidth;
	y2 = y1 + rbheight;
	border_color = border;
	fill_color = fill;
}

void Box::Display()
{
	BOX_TYPE box;

	// fill inside of box
	box.x1 = x1;
	box.y1 = y1;
	box.x2 = x2 - 2;
	box.y2 = y2 - 2;
	GraphicsHandler->FillBox(fill_color, &box);

	// add border to box
	box.x1 = x1;
	box.y1 = y1;
	box.x2 = x2 - 1;
	box.y2 = y2 - 1;
	GraphicsHandler->DrawBox(border_color, 
						SOLID_LINE, &box);
}

void Box::Color(COLOR_TYPE color)
{
	fill_color = color;
}



ShadedBox::ShadedBox(int x,
		int y,
		int width,
		int height,
		COLOR_TYPE shade,
		COLOR_TYPE border,
		COLOR_TYPE fill) : Icon(-1, -1, -1, -1)
{
	bottom_box = new BottomShadedBox(x, y,
				    width, height / 2,
				    shade, border, fill);

	top_box = new TopShadedBox(x, y + height / 2,
				    width, height / 2,
				    shade, border, fill);
}

void ShadedBox::Display()
{
	bottom_box->Display();
	top_box->Display();
}

void ShadedBox::Color(COLOR_TYPE color)
{
	bottom_box->Color(color);
	top_box->Color(color);
}

ShadedBox::~ShadedBox()
{
	delete bottom_box;
	delete top_box;
}



BottomShadedBox::BottomShadedBox(int x,
		int y,
		int width,
		int height,
		COLOR_TYPE shade,
		COLOR_TYPE border,
		COLOR_TYPE fill) :     Icon(-1, -1, -1, -1)
{
	x1 = x;
	y1 = y;
	x2 = x1 + width;
	y2 = y1 + height;

	shade_color = shade;
	border_color = border;
	fill_color = fill;
}

void BottomShadedBox::Display()
{
	BOX_TYPE box;

	int x = x1;
	int y = y1;
	int width = x2 - x1;
	int height = y2 - y1;

	box.x1 = x + 2;
	box.y1 = y + 2;
	box.x2 = x + width - 3;
	box.y2 = y + height;

	// fill inside of box
	GraphicsHandler->FillBox(fill_color, &box);

	// add BOTTOM border lines
	BOX_TYPE bottom_border;
	bottom_border.x1 = x;
	bottom_border.y1 = y;
	bottom_border.x2 = x + width - 1;
	bottom_border.y2 = y + 1;
	GraphicsHandler->FillBox(border_color, &bottom_border);

	// add LEFT border lines
	BOX_TYPE left_border;
	left_border.x1 = x;
	left_border.y1 = y;
	left_border.x2 = x + 1;
	left_border.y2 = y + height - 1;
	GraphicsHandler->FillBox(border_color, &left_border);

	// add RIGHT border lines
	BOX_TYPE right_border;
	right_border.x1 = x + width - 2;
	right_border.y1 = y;
	right_border.x2 = x + width - 1;
	right_border.y2 = y + height - 1;
	GraphicsHandler->FillBox(border_color, &right_border);

	// add BOTTOM shade
	BOX_TYPE bottom_shade;
	bottom_shade.x1 = x + 2;
	bottom_shade.y1 = y - 4;
	bottom_shade.x2 = x + width + 3;
	bottom_shade.y2 = y  - 1;
	GraphicsHandler->FillBox(shade_color, &bottom_shade);

	// add RIGHT shade
	BOX_TYPE right_shade;
	right_shade.x1 = x + width;
	right_shade.y1 = y - 1;
	right_shade.x2 = x + width + 3;
	right_shade.y2 = y + height - 1;
	GraphicsHandler->FillBox(shade_color, &right_shade);
}

void BottomShadedBox::Color(COLOR_TYPE color)
{
	fill_color = color;
}




TopShadedBox::TopShadedBox(int x,
		       int y,
		       int width,
		       int height,
		       COLOR_TYPE shade,
		       COLOR_TYPE border,
		       COLOR_TYPE fill) :  Icon(-1, -1, -1, -1)
{
	x1 = x;
	y1 = y;
	x2 = x1 + width;
	y2 = y1 + height;

	shade_color = shade;
	border_color = border;
	fill_color = fill;
}

void TopShadedBox::Display()
{
	int x = x1;
	int y = y1;
	int width = x2 - x1;
	int height = y2 - y1;

	BOX_TYPE box;
	box.x1 = x + 2;
	box.y1 = y;
	box.x2 = x + width - 3;
	box.y2 = y + height - 3;

	// fill inside of box
	GraphicsHandler->FillBox(fill_color, &box);

	// add TOP border lines
	BOX_TYPE border;
	border.x1 = x;
	border.y1 = y + height - 2;
	border.x2 = x + width - 1;
	border.y2 = y + height - 1;
	GraphicsHandler->FillBox(border_color, &border);

	// add LEFT border lines
	border.x1 = x;
	border.y1 = y;
	border.x2 = x + 1;
	border.y2 = y + height - 1;
	GraphicsHandler->FillBox(border_color, &border);

	// add RIGHT border lines
	border.x1 = x + width - 2;
	border.y1 = y;
	border.x2 = x + width - 1;
	border.y2 = y + height - 1;
	GraphicsHandler->FillBox(border_color, &border);

	// add RIGHT shade
	BOX_TYPE shade;
	shade.x1 = x + width;
	shade.y1 = y - 1;
	shade.x2 = x + width + 3;
	shade.y2 = y + height - 6;
	GraphicsHandler->FillBox(shade_color, &shade);
}

void TopShadedBox::Color(COLOR_TYPE color)
{
	fill_color = color;
}


